/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.tools.gml.servlet;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import javax.xml.bind.JAXBElement;

import net.disy.legato.tools.feature.ObjectFactory;
import net.opengis.gml.v_3_1_1.FeatureCollectionType;

public class GeometryServlet extends AbstractGeometryServlet {

	private static final long serialVersionUID = 1L;

	private String sessionAttributeName = "geometry";

	public String getSessionAttributeName() {
		return sessionAttributeName;
	}

	@Override
	public void init(ServletConfig config) throws ServletException {
		super.init(config);
		final String sessionAttributeName = config
				.getInitParameter("sessionAttributeName");
		if (sessionAttributeName != null) {
			this.sessionAttributeName = sessionAttributeName;
		}
	}

	@Override
	public Object getFeatureCollection(HttpServletRequest request,
			HttpServletResponse response) {

		HttpSession session = request.getSession(false);
		if (session == null) {
			return createFeatureCollection();
		} else {
			Object attribute = session.getAttribute(getSessionAttributeName());
			if (attribute != null) {
				return attribute;
			} else {
				return createFeatureCollection();
			}
		}
	}

	protected Object createFeatureCollection() {
		return new JAXBElement<FeatureCollectionType>(
				ObjectFactory.FEATURE_COLLECTION_QNAME,
				FeatureCollectionType.class, null, new FeatureCollectionType());
	}

	@Override
	public void setFeatureCollection(HttpServletRequest request,
			HttpServletResponse response, Object featureCollection) {
		HttpSession session = request.getSession();
		session.setAttribute(getSessionAttributeName(), featureCollection);
	}
}
